Module: MagicUserstamp::Controller
- Defined in:
- lib/magic_userstamp/controller.rb
Defined Under Namespace
Modules: InstanceMethods
Class Method Summary collapse
-
.included(base) ⇒ Object
The Userstamp module, when included into a controller, adds a before filter (named set_stamper) and an after filter (name reset_stamper).
Class Method Details
.included(base) ⇒ Object
The Userstamp module, when included into a controller, adds a before filter (named set_stamper) and an after filter (name reset_stamper). These methods assume a couple of things, but can be re-implemented in your controller to better suite your application.
See the documentation for set_stamper and reset_stamper for specific implementation details.
13 14 15 16 17 |
# File 'lib/magic_userstamp/controller.rb', line 13 def self.included(base) # :nodoc: base.send :include, InstanceMethods base.before_filter :set_stamper base.after_filter :reset_stamper end |